"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.usePredicateProperties = void 0;
/* eslint-disable import/prefer-default-export */
var react_1 = __importDefault(require("react"));
var gabby_query_protocol_lib_1 = require("gabby-query-protocol-lib");
// import { GQPPredicateEditorContext } from "../context";
// import type { TGQPPredicateEditorContextType } from "../context";
var context_1 = require("../context");
/**
 * "NodeId" sometimes referred to as predicateId.
 * The difference is context. Predicates have no ID. Nodes can be ID'd
 * the tree structure. nodeId can uniquely identify a predicate.
 *
 * @param nodeId - key to retrieve node,
 * @returns
 */
var usePredicateProperties = function (nodeId) {
    var _a = react_1.default.useContext(context_1.PredicateFormulaEditorContext.context), appendPredicate = _a.appendPredicate, getLeafIdsAll = _a.getLeafIdsAll, getPredicateById = _a.getPredicateById, getPredicateLeafById = _a.getPredicateLeafById, isRoot = _a.isRoot, makeEmptyPredicate = _a.makeEmptyPredicate, operatorLabels = _a.operatorLabels, removePredicate = _a.removePredicate, updatePredicate = _a.updatePredicate, subjectDictionary = _a.subjectDictionary;
    return {
        appendPredicate: function (newPredicate) {
            appendPredicate(nodeId, newPredicate);
        },
        getLeafIdsAll: getLeafIdsAll,
        getPredicateLeafProperties: function () {
            var predicateProperties = getPredicateLeafById(nodeId);
            var subjectProperties = subjectDictionary.getSubject(predicateProperties.subjectId);
            return { subjectProperties: subjectProperties, predicateProperties: predicateProperties };
        },
        isRoot: isRoot(nodeId),
        makeEmptyPredicate: makeEmptyPredicate,
        operatorLabels: operatorLabels,
        queryPredicate: getPredicateById(nodeId),
        removeMe: function () {
            removePredicate(nodeId);
        },
        removeCurrentPredicate: function () {
            removePredicate(nodeId);
        },
        subjectDictionary: subjectDictionary,
        updateMe: function (change) {
            updatePredicate(nodeId, change);
        },
        validatePredicateProperties: function (predicateProperties) {
            return gabby_query_protocol_lib_1.Validators.ValidatePredicateAgainstOperator(predicateProperties, subjectDictionary);
        },
    };
};
exports.usePredicateProperties = usePredicateProperties;
//# sourceMappingURL=usePredicateProperties.js.map